@@ -419,7 +419,7 @@ class HrefDefinitions:
 
     def get_asset_search_href(self, asset_type):
         return (SEARCH_ASSETS if not self._is_git_based_project() else GIT_BASED_PROJECT_SEARCH_ASSETS)\
-            .format(self._wml_credentials['url'], asset_type)
+            .format(self._get_cams_url_if_exists(), asset_type)
 
     def get_wsd_asset_type_href(self):
         return (ASSET_TYPE if not self._is_git_based_project() else GIT_BASED_PROJECT_ASSET_TYPE)\
