@@ -18,7 +18,7 @@ client combo
 import logging
 import socket
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import asyncio
 import signal
 import random
