@@ -245,8 +245,11 @@ def get_data_from_config(config):
     if config:
         data_config = {}
         try:
-            data_config['cls_ref'] = get_class_by_name(
-                config['path'], config['name'])
+            if 'class' in config:
+                data_config['cls_ref'] = config['class']
+            else:
+                data_config['cls_ref'] = get_class_by_name(
+                    config['path'], config['name'])
             data_config['info'] = config['info']
         except InvalidConfigurationException as ex:
             logger.exception(ex)
@@ -270,10 +273,12 @@ def get_model_from_config(config):
     if config:
         model_config = {}
         try:
-            model_config['cls_ref'] = get_class_by_name(
-                config['path'], config['name'])
+            if 'path' in config:
+                model_config['cls_ref'] = get_class_by_name(
+                    config['path'], config['name'])
 
-            model_config['spec'] = config['spec']
+            if 'spec' in config:
+                model_config['spec'] = config['spec']
 
             if 'info' in config:
                 model_config['info'] = config['info']
