@@ -678,27 +678,14 @@ class ModelCollection:
 
                     training_data_list.append(training_ref)
         else:
-            if artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA) is not None:
+            if artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA) and artifact.meta.prop(MetaNames.INPUT_DATA_SCHEMA) is None:
                 training_data_list=[]
                 training_data_ref_obj = artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA)
-                training_data_ref_obj["id"]="1"
-                import os
-                if "DEPLOYMENT_PLATFORM" in os.environ and os.environ["DEPLOYMENT_PLATFORM"] == "private":
-                    type_ = "fs"
-                else:
-                    type_ = "s3"
 
-                training_data_ref = {
-                    "id": "1",
-                    "type": type_,
-                    "connection": {"endpoint_url": "not_applicable",
-                     "access_key_id": "not_applicable",
-                     "secret_access_key": "not_applicable"},
-                    "location": {},
-                    "schema": training_data_ref_obj
-                }
+                if artifact.meta.prop(MetaNames.LABEL_FIELD):
+                    training_data_ref_obj['fields'] = [f for f in training_data_ref_obj['fields'] if f['name'] != artifact.meta.prop(MetaNames.LABEL_FIELD)]
 
-                training_data_list.append(training_data_ref)
+                artifact.meta.set(MetaNames.INPUT_DATA_SCHEMA, training_data_ref_obj)
 
         if artifact.meta.prop(MetaNames.SPACE_UID) is not None:
             spaceobj=artifact.meta.prop(MetaNames.SPACE_UID)
