@@ -286,9 +286,9 @@ class ModelDefinition(WMLResource):
 
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, model_definition_uid):
+    def get_details(self, model_definition_uid=None):
         """
-           Get metadata of stored model_definition.
+           Get metadata of stored model_definition. If no model_definition_uid is passed, details for all model_definitions will be returned.
 
 
            **Parameters**
@@ -308,44 +308,27 @@ class ModelDefinition(WMLResource):
             >>> model_definition_details = client.model_definitions.get_details(model_definition_uid)
 
         """
-        ##For CP4D, check if either spce or project ID is set
-        self._client._check_if_either_is_set()
-        op_name = 'getting model_definition details'
-        modeldef_uid = str_type_conv(model_definition_uid)
-        ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, False)
-
-        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
-
-        response_get = requests.get(
-            url,
-            params=self._client._params(),
-            headers=self._client._get_headers()
-        )
-
-        if response_get.status_code == 200:
-            get_model_definition_details = self._handle_response(200, op_name, response_get)
-            response = self._get_required_element_from_response(get_model_definition_details)
-
+        def get_required_element_from_response(response):
             if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
-
-                entity = response[u'entity']
-
-                try:
-                    del entity[u'wml_model_definition'][u'ml_version']
-                except KeyError:
-                    pass
-
                 final_response = {
                     "metadata": response[u'metadata'],
-                    "entity": entity
                 }
 
+                if 'entity' in response:
+                    entity = response[u'entity']
+
+                    try:
+                        del entity[u'wml_model_definition'][u'ml_version']
+                    except KeyError:
+                        pass
+
+                    final_response["entity"] = entity
+
                 return final_response
-            # return self._get_required_element_from_response(get_model_definition_details)
-        else:
-            return self._handle_response(200, op_name, response_get)
+
+        return self._get_asset_based_resource(model_definition_uid, 'wml_model_definition', get_required_element_from_response)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, model_definition_uid, filename, rev_id=None):
@@ -577,7 +560,11 @@ class ModelDefinition(WMLResource):
             headers=self._client._get_headers()
         )
         details = self._handle_response(200, op_name, response_get)
-        attachment_id = details["attachments"][0]["id"]
+        try:
+            attachment_id = details["attachments"][0]["id"]
+        except KeyError:
+            raise WMLClientError(f'No attachment exists for model definition (id={model_definition_uid}).')
+
         return attachment_id
 
     def list(self, limit=None):
