@@ -39,6 +39,8 @@ def process_heartbeat(client, **kwargs):
         hearbeat_resp_json = json.loads(hearbeat_resp.content.decode("utf-8"))
         service_version = hearbeat_resp_json.get("service_implementation")
 
+        if service_version.startswith("4.6"):
+            return "cpd460"
         if service_version.startswith("4.5") or service_version.startswith("45") or service_version.startswith("0.1.10000"):
             return "cpd450"
         if service_version.startswith("4.0"):
@@ -88,19 +90,22 @@ def import_diff(module_file_path):
 def choose_software_version(software_spec):
     if software_spec == "runtime-22.1-py3.9" or software_spec == "12b83a17-24d8-5082-900f-0ab31fbfd3cb":
         return "py39-tf27-pt110-sk10"
+    elif software_spec == "runtime-22.2-py3.10" or software_spec == "b56101f1-309d-549b-a849-eaa63f77b2fb":
+        return "py310-tf29-pt112-sk11"
     else:
         return "py38-tf24-pt17-sk23"
 
 
 def check_python_version(platform_env):
     py_version = platform.python_version()
-    if platform_env != "cloud" and platform_env != "cpd407" and platform_env != "cpd408" and platform_env != "cpd450":
+    if platform_env != "cloud" and platform_env != "cpd407" and platform_env != "cpd408" and platform_env != "cpd450" and platform_env != "cpd460":
         if not py_version.startswith("3.7.") and not py_version.startswith("3.8."):
             raise Exception("Python version {} is not supported for Federated Learning. "
                             "Parties must use a supported Python version to train the model. "
                             "For details, please refer to the documentation".format(py_version))
     else:
-        if not py_version.startswith("3.7.") and not py_version.startswith("3.8.") and not py_version.startswith("3.9"):
+        if not py_version.startswith("3.7.") and not py_version.startswith("3.8.") \
+                and not py_version.startswith("3.9") and not py_version.startswith("3.10"):
             raise Exception("Python version {} is not supported for Federated Learning. "
                             "Parties must use a supported Python version to train the model. "
                             "For details, please refer to the documentation".format(py_version))
@@ -128,8 +133,10 @@ class Party(WMLResource):
         'cpd407': "/cpd406/ibmfl",
         'cpd408': "/cpd406/ibmfl",
         'cpd450': "/cpd406/ibmfl",
+        'cpd460': "/cpd406/ibmfl",
         'py38-tf24-pt17-sk23': "/py38-tf24-pt17-sk23/ibmfl", #default
-        'py39-tf27-pt110-sk10': "/py39-tf27-pt110-sk10/ibmfl"
+        'py39-tf27-pt110-sk10': "/py39-tf27-pt110-sk10/ibmfl",
+        'py310-tf29-pt112-sk11': "/py310-tf29-pt112-sk11/ibmfl"
     }
 
     def __init__(self, client=None, **kwargs):
