@@ -170,8 +170,8 @@ class Training(WMLResource):
                     raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
                 elif self._client.ICP:
                     print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
-                #else:
-                #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
+                else:
+                    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
 
             return details
 
